@@ -1,7 +1,7 @@
 from tempfile import mkdtemp
 
 from django.apps import apps as django_apps
-from django.test import TestCase, override_settings
+from django.test import TestCase, override_settings, tag
 
 from edc_randomization.randomization_list_verifier import RandomizationListError
 from edc_randomization.system_checks import (
@@ -29,6 +29,7 @@ class TestRandomizer(TestCaseMixin, TestCase):
             force_verify=True,
         )
 
+    @tag("1")
     @override_settings(ETC_DIR=mkdtemp(), DEBUG=False)
     def test_randomization_list_check_verify(self):
         from django.conf import settings
@@ -44,7 +45,6 @@ class TestRandomizer(TestCaseMixin, TestCase):
         EDC_RANDOMIZATION_BLINDED_TRIAL=False, EDC_RANDOMIZATION_UNBLINDED_USERS=["audrey"]
     )
     def test_blinded_trial_settings_check(self):
-
         errors = blinded_trial_settings_check(
             app_configs=django_apps.get_app_config("edc_randomization")
         )
@@ -54,7 +54,6 @@ class TestRandomizer(TestCaseMixin, TestCase):
         EDC_RANDOMIZATION_BLINDED_TRIAL=True, EDC_RANDOMIZATION_UNBLINDED_USERS=["audrey"]
     )
     def test_blinded_trial_settings_check2(self):
-
         errors = blinded_trial_settings_check(
             app_configs=django_apps.get_app_config("edc_randomization")
         )
