@@ -8,7 +8,7 @@ from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ObjectDoesNotExist
 from edc_pdutils.model_to_dataframe import ModelToDataframe
-from edc_sites import get_site_id
+from edc_sites.site import sites
 from edc_utils import get_utcnow
 
 from .site_randomizers import site_randomizers
@@ -53,7 +53,10 @@ def get_assignment_description_for_subject(
 
 
 def get_object_for_subject(
-    subject_identifier: str, randomizer_name: str = None, identifier_fld: str | None = None
+    subject_identifier: str,
+    randomizer_name: str = None,
+    identifier_fld: str | None = None,
+    label: str | None = None,
 ) -> Any:
     """Returns a randomization list model instance or raises
     for the given subject.
@@ -61,9 +64,11 @@ def get_object_for_subject(
     Calling this method before a subject is randomized will
     raise a SubjectNotRandomization error.
     """
+    identifier_fld = identifier_fld or "subject_identifier"
+    label = label or "subject"
     randomizer_cls = site_randomizers.get(randomizer_name)
     opts = {
-        identifier_fld or "subject_identifier": subject_identifier,
+        identifier_fld: subject_identifier,
         "randomizer_name": randomizer_name,
         "allocated": True,
         "allocated_datetime__isnull": False,
@@ -72,8 +77,8 @@ def get_object_for_subject(
         obj = randomizer_cls.model_cls().objects.get(**opts)
     except ObjectDoesNotExist:
         raise SubjectNotRandomization(
-            f"Subject not randomized. Randomizer name is `{randomizer_name}`. "
-            f"Got {subject_identifier}."
+            f"{label.title()} not randomized. See Randomizer `{randomizer_name}`. "
+            f"Got {identifier_fld}=`{subject_identifier}`."
         )
     return obj
 
@@ -106,7 +111,7 @@ def generate_fake_randomization_list(
         raise ValueError(f"Invalid assignment. Got {assignment}")
 
     # get site ID and write the file
-    site_id = get_site_id(site_name, sites=all_sites[country])
+    site_id = sites.get_by_attr("name", site_name)
     with open(filename, "a+", newline="") as f:
         writer = csv.DictWriter(f, fieldnames=["sid", "assignment", "site_name", "country"])
         if write_header:
